@@ -461,6 +461,109 @@ def _create_hkjc_hkjc_player_model(
         inherited_runners=None,
         inherited_scores=None,
         effective_field_goal_percentage=None,
+        penalty_kicks_made=None,
+        penalty_kicks_attempted=None,
+        shots_total=None,
+        shots_on_target=None,
+        yellow_cards=None,
+        red_cards=None,
+        touches=None,
+        expected_goals=None,
+        non_penalty_expected_goals=None,
+        expected_assisted_goals=None,
+        shot_creating_actions=None,
+        goal_creating_actions=None,
+        passes_completed=None,
+        passes_attempted=None,
+        pass_completion=None,
+        progressive_passes=None,
+        carries=None,
+        progressive_carries=None,
+        take_ons_attempted=None,
+        successful_take_ons=None,
+        total_passing_distance=None,
+        progressive_passing_distance=None,
+        passes_completed_short=None,
+        passes_attempted_short=None,
+        pass_completion_short=None,
+        passes_completed_medium=None,
+        passes_attempted_medium=None,
+        pass_completion_medium=None,
+        passes_completed_long=None,
+        passes_attempted_long=None,
+        pass_completion_long=None,
+        expected_assists=None,
+        key_passes=None,
+        passes_into_final_third=None,
+        passes_into_penalty_area=None,
+        crosses_into_penalty_area=None,
+        live_ball_passes=None,
+        dead_ball_passes=None,
+        passes_from_free_kicks=None,
+        through_balls=None,
+        switches=None,
+        crosses=None,
+        throw_ins_taken=None,
+        corner_kicks=None,
+        inswinging_corner_kicks=None,
+        outswinging_corner_kicks=None,
+        straight_corner_kicks=None,
+        passes_offside=None,
+        passes_blocked=None,
+        tackles_won=None,
+        tackles_in_defensive_third=None,
+        tackles_in_middle_third=None,
+        tackles_in_attacking_third=None,
+        dribblers_tackled=None,
+        dribbles_challenged=None,
+        percent_of_dribblers_tackled=None,
+        challenges_lost=None,
+        shots_blocked=None,
+        tackles_plus_interceptions=None,
+        errors=None,
+        touches_in_defensive_penalty_area=None,
+        touches_in_defensive_third=None,
+        touches_in_middle_third=None,
+        touches_in_attacking_third=None,
+        touches_in_attacking_penalty_area=None,
+        live_ball_touches=None,
+        successful_take_on_percentage=None,
+        times_tackled_during_take_ons=None,
+        tackled_during_take_on_percentage=None,
+        total_carrying_distance=None,
+        progressive_carrying_distance=None,
+        carries_into_final_third=None,
+        carries_into_penalty_area=None,
+        miscontrols=None,
+        dispossessed=None,
+        passes_received=None,
+        progressive_passes_received=None,
+        second_yellow_card=None,
+        fouls_committed=None,
+        fouls_drawn=None,
+        offsides=None,
+        penalty_kicks_won=None,
+        penalty_kicks_conceded=None,
+        own_goals=None,
+        ball_recoveries=None,
+        aerials_won=None,
+        aerials_lost=None,
+        percentage_of_aerials_won=None,
+        shots_on_target_against=None,
+        post_shot_expected_goals=None,
+        passes_attempted_minus_goal_kicks=None,
+        throws_attempted=None,
+        percentage_of_passes_that_were_launched=None,
+        average_pass_length=None,
+        goal_kicks_attempted=None,
+        percentage_of_goal_kicks_that_were_launched=None,
+        average_goal_kick_length=None,
+        crosses_faced=None,
+        crosses_stopped=None,
+        percentage_crosses_stopped=None,
+        defensive_actions_outside_penalty_area=None,
+        average_distance_of_defensive_actions=None,
+        three_point_attempt_rate=None,
     )
 
 
